CommandEscPosBitImage class

Inheritance

Constructors

CommandEscPosBitImage(int mode, int nL, int nH, List<int> data, {bool lineBreak = false})
CommandEscPosBitImage.fromJson(Map json)
factory

Properties

data List<int>
final
hashCode int
The hash code for this object.
no setterinherited
lineBreak bool
final
mode int
final
name String
Command name.
finalinherited
nH int
final
nL int
final
parameters List
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts into a JSON-compatible map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited