CommandEscPosText class

Inheritance

Constructors

CommandEscPosText(String text)
CommandEscPosText.fromJson(Map json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Command name.
finalinherited
parameters List
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts into a JSON-compatible map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited