reset method
Resets the decoder state, preparing it for a new decoding process.
Implementation
@override
void reset() {
_output.clear();
_textBuffer = null;
}
Resets the decoder state, preparing it for a new decoding process.
@override
void reset() {
_output.clear();
_textBuffer = null;
}