CharCodeTableEscPos enum
ESC/POS character code tables.
Used with the ESC/POS command: ESC t n
Notes:
- Support varies by printer model and firmware.
- After
ESC @, the printer reverts to its factory default table (commonly PC437 or PC850). - Text must be encoded according to the selected table before printing.
Values
- pc437 → const CharCodeTableEscPos
-
PC437 — USA (default on many printers)
const CharCodeTableEscPos(0, 'cp437') - pc850 → const CharCodeTableEscPos
-
PC850 — Multilingual (Western Europe, OEM)
const CharCodeTableEscPos(2, 'cp850') - pc860 → const CharCodeTableEscPos
-
PC860 — Portuguese
const CharCodeTableEscPos(3, 'cp860') - pc863 → const CharCodeTableEscPos
-
PC863 — Canadian French
const CharCodeTableEscPos(4, 'cp863') - pc865 → const CharCodeTableEscPos
-
PC865 — Nordic
const CharCodeTableEscPos(5, 'cp865') - wpc1252 → const CharCodeTableEscPos
-
Windows-1252 — Western Europe (Latin-1 superset)
const CharCodeTableEscPos(16, 'windows1252') - latin1 → const CharCodeTableEscPos
-
LATIN-1: Alias to Windows-1252 — Western Europe (Latin-1 superset)
const CharCodeTableEscPos(16, 'windows1252') - pc866 → const CharCodeTableEscPos
-
PC866 — Cyrillic
const CharCodeTableEscPos(17, 'cp866') - pc852 → const CharCodeTableEscPos
-
PC852 — Central Europe
const CharCodeTableEscPos(18, 'cp852') - pc858 → const CharCodeTableEscPos
-
PC858 — Multilingual with Euro sign
const CharCodeTableEscPos(19, 'cp858') - pc864 → const CharCodeTableEscPos
-
PC864 — Arabic
const CharCodeTableEscPos(20, 'cp864') - pc737 → const CharCodeTableEscPos
-
PC737 — Greek
const CharCodeTableEscPos(21, 'cp737') - pc857 → const CharCodeTableEscPos
-
PC857 — Turkish
const CharCodeTableEscPos(22, 'cp857') - pc862 → const CharCodeTableEscPos
-
PC862 — Hebrew
const CharCodeTableEscPos(23, 'cp862') - pc874 → const CharCodeTableEscPos
-
PC874 — Thai
const CharCodeTableEscPos(24, 'windows874') - wpc1250 → const CharCodeTableEscPos
-
Windows-1250 — Central Europe
const CharCodeTableEscPos(25, 'windows1250') - wpc1251 → const CharCodeTableEscPos
-
Windows-1251 — Cyrillic
const CharCodeTableEscPos(26, 'windows1251') - wpc1253 → const CharCodeTableEscPos
-
Windows-1253 — Greek
const CharCodeTableEscPos(27, 'windows1253') - wpc1254 → const CharCodeTableEscPos
-
Windows-1254 — Turkish
const CharCodeTableEscPos(28, 'windows1254') - wpc1255 → const CharCodeTableEscPos
-
Windows-1255 — Hebrew
const CharCodeTableEscPos(29, 'windows1255') - wpc1256 → const CharCodeTableEscPos
-
Windows-1256 — Arabic
const CharCodeTableEscPos(30, 'windows1256') - wpc1257 → const CharCodeTableEscPos
-
Windows-1257 — Baltic
const CharCodeTableEscPos(31, 'windows1257') - wpc1258 → const CharCodeTableEscPos
-
Windows-1258 — Vietnamese
const CharCodeTableEscPos(32, 'windows1258')
Properties
- charset → String?
-
final
- code → int
-
Numeric value used by the
ESC t ncommand.final - encoder → CharsetEncoder?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCode(
int code) → CharCodeTableEscPos?
Constants
-
values
→ const List<
CharCodeTableEscPos> - A constant List of the values in this enum, in order of their declaration.