DecoderEscPos class
Decodes ESC/POS commands from received print data, extracting text, formatting, and control instructions.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
List< int> serial, {int offset = 0, int? length}) → List<CommandEscPos> -
Decodes a sequence of bytes (
serial) into a list of commands.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
Resets the decoder state, preparing it for a new decoding process.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited