PosStyles class
Text styles
Constructors
- PosStyles({bool bold = false, bool reverse = false, bool underline = false, bool turn90 = false, PosAlign? align, PosTextSize? height, PosTextSize? width, PosFontType? fontType, String? codeTable, bool isKanji = false})
-
const
- PosStyles.defaults({bool bold = false, bool reverse = false, bool underline = false, bool turn90 = false, PosAlign? align = PosAlign.left, PosTextSize? height = PosTextSize.size1, PosTextSize? width = PosTextSize.size1, PosFontType? fontType = PosFontType.fontA, String? codeTable = "CP437", bool isKanji = false})
-
const
Properties
- align → PosAlign?
-
final
- bold → bool
-
final
- codeTable → String?
-
final
- fontType → PosFontType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → PosTextSize?
-
final
- isKanji → bool
-
final
- reverse → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- turn90 → bool
-
final
- underline → bool
-
final
- width → PosTextSize?
-
final
Methods
-
copyWith(
{bool? bold, bool? reverse, bool? underline, bool? turn90, PosAlign? align, PosTextSize? height, PosTextSize? width, PosFontType? fontType, String? codeTable, bool? isKanji}) → PosStyles -
copyWithDefaults(
{PosAlign? align, PosTextSize? height, PosTextSize? width, PosFontType? fontType, String? codeTable, PosStyles? stylesDefaults}) → PosStyles -
ensureWithCodeTable(
{String defaultCodeTable = 'CP437'}) → PosStyles -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited